@@ -7,12 +7,10 @@ legit.core
 This module provides the basic functionality of legit.
 """
 
-# from clint import resources
+from . import bootstrap
+del bootstrap
 
-__version__ = '0.0.9'
+__version__ = '0.4.1'
 __author__ = 'Kenneth Reitz'
 __license__ = 'BSD'
 
-
-# resources.init('kennethreitz', 'legit')
-# resources.user.write('config.ini', "we'll get there.")
\ No newline at end of file
